@@ -75,7 +75,7 @@ class NormalDistribution(QuantumCircuit):
     Examples:
 
         >>> circuit = NormalDistribution(3, mu=1, sigma=1, bounds=(0, 2))
-        >>> circuit.draw()
+        >>> circuit.decompose().draw()
              ┌────────────────────────────────────────────────────────────────────────────┐
         q_0: ┤0                                                                           ├
              │                                                                            │
@@ -166,11 +166,11 @@ class NormalDistribution(QuantumCircuit):
             bounds = (-1, 1) if dim == 1 else [(-1, 1)] * dim
 
         if isinstance(num_qubits, int):  # univariate case
-            super().__init__(num_qubits, name=name)
+            inner = QuantumCircuit(num_qubits, name=name)
 
             x = np.linspace(bounds[0], bounds[1], num=2 ** num_qubits)  # type: Any
         else:  # multivariate case
-            super().__init__(sum(num_qubits), name=name)
+            inner = QuantumCircuit(sum(num_qubits), name=name)
 
             # compute the evaluation points using numpy.meshgrid
             # indexing 'ij' yields the "column-based" indexing
@@ -195,16 +195,20 @@ class NormalDistribution(QuantumCircuit):
         self._probabilities = normalized_probabilities
         self._bounds = bounds
 
+        super().__init__(*inner.qregs, name=name)
+
         # use default the isometry (or initialize w/o resets) algorithm to construct the circuit
         # pylint: disable=no-member
         if upto_diag:
-            self.isometry(np.sqrt(normalized_probabilities), self.qubits, None)
+            inner.isometry(np.sqrt(normalized_probabilities), inner.qubits, None)
+            self.append(inner.to_instruction(), inner.qubits)  # Isometry is not a Gate
         else:
             from qiskit.extensions import Initialize  # pylint: disable=cyclic-import
 
             initialize = Initialize(np.sqrt(normalized_probabilities))
             circuit = initialize.gates_to_uncompute().inverse()
-            self.compose(circuit, inplace=True)
+            inner.compose(circuit, inplace=True)
+            self.append(inner.to_gate(), inner.qubits)
 
     @property
     def values(self) -> np.ndarray:
@@ -230,18 +234,16 @@ def _check_dimensions_match(num_qubits, mu, sigma, bounds):
         mu = [mu] if not isinstance(mu, (list, np.ndarray)) else mu
         if len(mu) != dim:
             raise ValueError(
-                "Dimension of mu ({}) does not match the dimension of the "
-                "random variable specified by the number of qubits ({})"
-                "".format(len(mu), dim)
+                f"Dimension of mu ({len(mu)}) does not match the dimension of the "
+                f"random variable specified by the number of qubits ({dim})"
             )
 
     if sigma is not None:
         sigma = [[sigma]] if not isinstance(sigma, (list, np.ndarray)) else sigma
         if len(sigma) != dim or len(sigma[0]) != dim:
             raise ValueError(
-                "Dimension of sigma ({} x {}) does not match the dimension of "
-                "the random variable specified by the number of qubits ({})"
-                "".format(len(sigma), len(sigma[0]), dim)
+                f"Dimension of sigma ({len(sigma)} x {len(sigma[0])}) does not match the dimension of "
+                f"the random variable specified by the number of qubits ({dim})"
             )
 
     if bounds is not None:
@@ -250,9 +252,8 @@ def _check_dimensions_match(num_qubits, mu, sigma, bounds):
         bounds = [bounds] if not isinstance(bounds[0], tuple) else bounds
         if len(bounds) != dim:
             raise ValueError(
-                "Dimension of bounds ({}) does not match the dimension of the "
-                "random variable specified by the number of qubits ({})"
-                "".format(len(bounds), dim)
+                f"Dimension of bounds ({len(bounds)}) does not match the dimension of the "
+                f"random variable specified by the number of qubits ({dim})"
             )
 
 
@@ -265,7 +266,6 @@ def _check_bounds_valid(bounds):
     for i, bound in enumerate(bounds):
         if not bound[1] - bound[0] > 0:
             raise ValueError(
-                "Dimension {} of the bounds are invalid, must be a non-empty "
+                f"Dimension {i} of the bounds are invalid, must be a non-empty "
                 "interval where the lower bounds is smaller than the upper bound."
-                "".format(i)
             )
