@@ -54,7 +54,7 @@ class TestEuropeanCallDelta(QiskitFinanceTestCase):
                 Aer,
             )  # pylint: disable=unused-import,import-outside-toplevel
         except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest("Aer doesn't appear to be installed. Error: '{}'".format(str(ex)))
+            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
             return
 
         num_qubits = 3
@@ -81,7 +81,7 @@ class TestEuropeanCallDelta(QiskitFinanceTestCase):
         # construct circuit factory for uncertainty model
         uncertainty_model = LogNormalDistribution(
             num_qubits, mu=mu, sigma=sigma ** 2, bounds=bounds
-        )
+        ).decompose()
 
         # set the strike price (should be within the low and the high value of the uncertainty)
         strike_price = 1.896
@@ -106,7 +106,7 @@ class TestEuropeanCallDelta(QiskitFinanceTestCase):
         )
         iae = IterativeAmplitudeEstimation(epsilon_target=0.01, alpha=0.05, quantum_instance=q_i)
         result = iae.estimate(problem)
-        self.assertAlmostEqual(result.estimation_processed, 0.8079816552117238)
+        self.assertAlmostEqual(result.estimation_processed, 0.8088790606143996)
 
 
 if __name__ == "__main__":
